%global pypi_name qrcode

Name:           python-%{pypi_name}
Version:        7.3.1
Release:        %mkrel 3
Summary:        Python QR Code image generator
Group:          Development/Python
License:        BSD
URL:            https://pypi.org/project/qrcode/
Source0:        %{pypi_source}
BuildArch:      noarch
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-imaging
BuildRequires:  python3-six
BuildRequires:  python3-mock

%description
This module uses the Python Imaging Library (PIL) to allow for the \
generation of QR Codes.

%package -n python3-%{pypi_name}
Summary:        Python QR Code image generator
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
Requires:       python3-imaging
# For entry point:
Requires:       python3-setuptools
Requires:       python3-%{pypi_name}-core = %{version}-%{release}

%description -n python3-%{pypi_name}
This module uses the Python Imaging Library (PIL) to allow for the \
generation of QR Codes.

%package -n python3-%{pypi_name}-core
Summary:        QR Code image generator (core library)
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}-core}
Requires:       python3-six

%description -n python3-%{pypi_name}-core
Core Python module for QR code generation. Does not contain image rendering.

%prep
%setup -q -n %{pypi_name}-%{version}

# The pure plugin requires pymaging which is not packaged
rm qrcode/image/pure.py*

# Remove shebang
sed -i '1d'  qrcode/console_scripts.py

%build
%py3_build

%install
%py3_install

# Do not install tests
rm -r %{buildroot}%{python3_sitelib}/%{pypi_name}/tests

#
# In previous iterations of the package, the qr script had been
# renamed to qrcode. This was an unnecessary change from upstream.
#
# We cary this symlink to maintain compat with old packages.
#
ln -s qr %{buildroot}%{_bindir}/qrcode

%check
# in lieue of a real test suite
modules=$(find qrcode -name '*.py' \
          | grep -v __init__ \
          | sort \
          | sed -e 's|/|.|g' \
          | sed -e 's|.py$||g');


for m in $modules;
do
    %{__python3} -c "import $m"
done

%files -n python3-%{pypi_name}
%doc README.rst CHANGES.rst
%license LICENSE
%{_bindir}/qr
%{_bindir}/qrcode
%{_mandir}/man1/qr.1*
%{python3_sitelib}/%{pypi_name}/image/svg.py*
%{python3_sitelib}/%{pypi_name}/image/pil.py*
%{python3_sitelib}/%{pypi_name}/image/__pycache__/svg.*
%{python3_sitelib}/%{pypi_name}/image/__pycache__/pil.*

%files  -n python3-%{pypi_name}-core
%doc README.rst CHANGES.rst
%license LICENSE
%dir %{python3_sitelib}/%{pypi_name}/
%dir %{python3_sitelib}/%{pypi_name}/image
%dir %{python3_sitelib}/%{pypi_name}/image/__pycache__
%{python3_sitelib}/%{pypi_name}*.egg-info
%{python3_sitelib}/%{pypi_name}/*.py*
%{python3_sitelib}/%{pypi_name}/__pycache__
%{python3_sitelib}/%{pypi_name}/image/__init__.py*
%{python3_sitelib}/%{pypi_name}/image/base.py*
%{python3_sitelib}/%{pypi_name}/image/styledpil.py*
%{python3_sitelib}/%{pypi_name}/image/styles/
%{python3_sitelib}/%{pypi_name}/image/__pycache__/__init__.*
%{python3_sitelib}/%{pypi_name}/image/__pycache__/base.*
%{python3_sitelib}/%{pypi_name}/image/__pycache__/styledpil.*


%changelog
* Wed Apr 06 2022 umeabot <umeabot> 7.3.1-3.mga9
+ Revision: 1845993
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 mrambo3501 <mrambo3501> 7.3.1-2.mga9
+ Revision: 1778383
- rebuild for python-3.10

* Sat Nov 06 2021 joequant <joequant> 7.3.1-1.mga9
+ Revision: 1754082
- update to 7.3.1

* Thu Apr 01 2021 guillomovitch <guillomovitch> 6.1-3.mga9
+ Revision: 1712544
- rebuild for python 3.9

* Sun Feb 16 2020 umeabot <umeabot> 6.1-2.mga8
+ Revision: 1532776
- Mageia 8 Mass Rebuild

* Tue Sep 17 2019 wally <wally> 6.1-1.mga8
+ Revision: 1443133
- rebuild for python3.8
- drop python2 support

* Sat Apr 20 2019 wally <wally> 6.1-1.mga7
+ Revision: 1393779
- new version 6.1

* Thu Jan 10 2019 shlomif <shlomif> 6.0-4.mga7
+ Revision: 1354041
- Rebuild for python3 3.7

* Sat Oct 13 2018 joequant <joequant> 6.0-3.mga7
+ Revision: 1320104
- fix provides to have python-qrcode

* Sun Oct 07 2018 wally <wally> 6.0-2.mga7
+ Revision: 1318535
- obsolete old python-qrcode

* Sun Oct 07 2018 joequant <joequant> 6.0-1.mga7
+ Revision: 1318377
- upgrade to 6.0 - change python2 conventions

* Thu Sep 20 2018 umeabot <umeabot> 5.3-3.mga7
+ Revision: 1289984
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 5.3-2.mga7
+ Revision: 1135597
- Rebuild for python 3.6

* Sun Nov 20 2016 joequant <joequant> 5.3-1.mga6
+ Revision: 1068412
- imported package python-qrcode

